@@ -10,43 +10,43 @@ import yaml
 from itertools import chain
 from copy import deepcopy
 
+from typing import Any, Dict, Optional, Tuple
+
 
 logger = logging.getLogger(__name__)
 
 
 SWH_CONFIG_DIRECTORIES = [
-    '~/.config/swh',
-    '~/.swh',
-    '/etc/softwareheritage',
+    "~/.config/swh",
+    "~/.swh",
+    "/etc/softwareheritage",
 ]
 
-SWH_GLOBAL_CONFIG = 'global.ini'
+SWH_GLOBAL_CONFIG = "global.ini"
 
 SWH_DEFAULT_GLOBAL_CONFIG = {
-    'content_size_limit': ('int', 100 * 1024 * 1024),
-    'log_db': ('str', 'dbname=softwareheritage-log'),
+    "max_content_size": ("int", 100 * 1024 * 1024),
+    "log_db": ("str", "dbname=softwareheritage-log"),
 }
 
 SWH_CONFIG_EXTENSIONS = [
-    '.yml',
-    '.ini',
+    ".yml",
+    ".ini",
 ]
 
 # conversion per type
 _map_convert_fn = {
-    'int': int,
-    'bool': lambda x: x.lower() == 'true',
-    'list[str]': lambda x: [value.strip() for value in x.split(',')],
-    'list[int]': lambda x: [int(value.strip()) for value in x.split(',')],
+    "int": int,
+    "bool": lambda x: x.lower() == "true",
+    "list[str]": lambda x: [value.strip() for value in x.split(",")],
+    "list[int]": lambda x: [int(value.strip()) for value in x.split(",")],
 }
 
 _map_check_fn = {
-    'int': lambda x: isinstance(x, int),
-    'bool': lambda x: isinstance(x, bool),
-    'list[str]': lambda x: (isinstance(x, list) and
-                            all(isinstance(y, str) for y in x)),
-    'list[int]': lambda x: (isinstance(x, list) and
-                            all(isinstance(y, int) for y in x)),
+    "int": lambda x: isinstance(x, int),
+    "bool": lambda x: isinstance(x, bool),
+    "list[str]": lambda x: (isinstance(x, list) and all(isinstance(y, str) for y in x)),
+    "list[int]": lambda x: (isinstance(x, list) and all(isinstance(y, int) for y in x)),
 }
 
 
@@ -76,7 +76,7 @@ def exists_accessible(file):
 
 def config_basepath(config_path):
     """Return the base path of a configuration file"""
-    if config_path.endswith(('.ini', '.yml')):
+    if config_path.endswith((".ini", ".yml")):
         return config_path[:-4]
 
     return config_path
@@ -87,22 +87,21 @@ def read_raw_config(base_config_path):
 
     Can read yml or ini files.
     """
-    yml_file = base_config_path + '.yml'
+    yml_file = base_config_path + ".yml"
     if exists_accessible(yml_file):
-        logger.info('Loading config file %s', yml_file)
+        logger.info("Loading config file %s", yml_file)
         with open(yml_file) as f:
             return yaml.safe_load(f)
 
-    ini_file = base_config_path + '.ini'
+    ini_file = base_config_path + ".ini"
     if exists_accessible(ini_file):
         config = configparser.ConfigParser()
         config.read(ini_file)
-        if 'main' in config._sections:
-            logger.info('Loading config file %s', ini_file)
-            return config._sections['main']
+        if "main" in config._sections:
+            logger.info("Loading config file %s", ini_file)
+            return config._sections["main"]
         else:
-            logger.warning('Ignoring config file %s (no [main] section)',
-                           ini_file)
+            logger.warning("Ignoring config file %s (no [main] section)", ini_file)
 
     return {}
 
@@ -110,8 +109,9 @@ def read_raw_config(base_config_path):
 def config_exists(config_path):
     """Check whether the given config exists"""
     basepath = config_basepath(config_path)
-    return any(exists_accessible(basepath + extension)
-               for extension in SWH_CONFIG_EXTENSIONS)
+    return any(
+        exists_accessible(basepath + extension) for extension in SWH_CONFIG_EXTENSIONS
+    )
 
 
 def read(conf_file=None, default_conf=None):
@@ -231,8 +231,7 @@ def merge_configs(base, other):
     Note that no type checking is done for anything but dicts.
     """
     if not isinstance(base, dict) or not isinstance(other, dict):
-        raise TypeError(
-            'Cannot merge a %s with a %s' % (type(base), type(other)))
+        raise TypeError("Cannot merge a %s with a %s" % (type(base), type(other)))
 
     output = {}
     allkeys = set(chain(base.keys(), other.keys()))
@@ -256,13 +255,13 @@ def swh_config_paths(base_filename):
     """Return the Software Heritage specific configuration paths for the given
        filename."""
 
-    return [os.path.join(dirname, base_filename)
-            for dirname in SWH_CONFIG_DIRECTORIES]
+    return [os.path.join(dirname, base_filename) for dirname in SWH_CONFIG_DIRECTORIES]
 
 
 def prepare_folders(conf, *keys):
     """Prepare the folder mentioned in config under keys.
     """
+
     def makedir(folder):
         if not os.path.exists(folder):
             os.makedirs(folder)
@@ -275,8 +274,7 @@ def load_global_config():
     """Load the global Software Heritage config"""
 
     return priority_read(
-        swh_config_paths(SWH_GLOBAL_CONFIG),
-        SWH_DEFAULT_GLOBAL_CONFIG,
+        swh_config_paths(SWH_GLOBAL_CONFIG), SWH_DEFAULT_GLOBAL_CONFIG,
     )
 
 
@@ -311,12 +309,17 @@ class SWHConfig:
 
     """
 
-    DEFAULT_CONFIG = {}
-    CONFIG_BASE_FILENAME = ''
+    DEFAULT_CONFIG = {}  # type: Dict[str, Tuple[str, Any]]
+    CONFIG_BASE_FILENAME = ""  # type: Optional[str]
 
     @classmethod
-    def parse_config_file(cls, base_filename=None, config_filename=None,
-                          additional_configs=None, global_config=True):
+    def parse_config_file(
+        cls,
+        base_filename=None,
+        config_filename=None,
+        additional_configs=None,
+        global_config=True,
+    ):
         """Parse the configuration file associated to the current class.
 
         By default, parse_config_file will load the configuration
@@ -326,21 +329,21 @@ class SWHConfig:
         lookup completely).
 
         Args:
-            - base_filename (str) overrides the default
-                cls.CONFIG_BASE_FILENAME
-            - config_filename (str) sets the file to parse instead of
-                the defaults set from cls.CONFIG_BASE_FILENAME
-            - additional_configs (list of default configuration dicts)
-                allows to override or extend the configuration set in
-                cls.DEFAULT_CONFIG.
+            - base_filename (str): overrides the default
+              cls.CONFIG_BASE_FILENAME
+            - config_filename (str): sets the file to parse instead of
+              the defaults set from cls.CONFIG_BASE_FILENAME
+            - additional_configs: (list of default configuration dicts)
+              allows to override or extend the configuration set in
+              cls.DEFAULT_CONFIG.
             - global_config (bool): Load the global configuration (default:
-                True)
+              True)
         """
 
         if config_filename:
             config_filenames = [config_filename]
-        elif 'SWH_CONFIG_FILENAME' in os.environ:
-            config_filenames = [os.environ['SWH_CONFIG_FILENAME']]
+        elif "SWH_CONFIG_FILENAME" in os.environ:
+            config_filenames = [os.environ["SWH_CONFIG_FILENAME"]]
         else:
             if not base_filename:
                 base_filename = cls.CONFIG_BASE_FILENAME
@@ -348,8 +351,9 @@ class SWHConfig:
         if not additional_configs:
             additional_configs = []
 
-        full_default_config = merge_default_configs(cls.DEFAULT_CONFIG,
-                                                    *additional_configs)
+        full_default_config = merge_default_configs(
+            cls.DEFAULT_CONFIG, *additional_configs
+        )
 
         config = {}
         if global_config:
